#
# spec file for package ghc-vector-algorithms
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name vector-algorithms
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.9.0.3
Release:        1.4
Summary:        Efficient algorithms for vector arrays
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bitvec-devel
BuildRequires:  ghc-bitvec-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-primitive-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
%endif

%description
Efficient algorithms for sorting vector arrays. At some stage other vector
algorithms may be added.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Nov 24 2024 Peter Simons <psimons@suse.com>
- Update vector-algorithms to version 0.9.0.3.
  [#]# Version 0.9.0.3 (2024-11-25)
  - Fix an off-by-one error Heap.partialSort functions.
  - Support latest ghcs.
* Mon May 27 2024 Peter Simons <psimons@suse.com>
- Update vector-algorithms to version 0.9.0.2 revision 1.
  [#]# Version 0.9.0.2 (2024-05-23)
  - Add `TypeOperators` pragma where needed.
* Tue Oct 10 2023 Peter Simons <psimons@suse.com>
- Update vector-algorithms to version 0.9.0.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Fri Mar 10 2023 Peter Simons <psimons@suse.com>
- Update vector-algorithms to version 0.9.0.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Oct  8 2022 Peter Simons <psimons@suse.com>
- Update vector-algorithms to version 0.9.0.1 revision 1.
  [#]# Version 0.9.0.1 (2022-07-28)
  - Allow building with vector-0.13.*.
  [#]# Version 0.9.0.0 (2022-05-19)
  - Add nub related functions.
  - Add sortUniq related functions (sorts, then removes duplicates).
* Mon Jun 20 2022 Peter Simons <psimons@suse.com>
- Update vector-algorithms to version 0.8.0.4 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Feb  8 2021 psimons@suse.com
- Update vector-algorithms to version 0.8.0.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sun Dec  6 2020 psimons@suse.com
- Update vector-algorithms to version 0.8.0.4.
  [#]# Version 0.8.0.4 (2020-12-06)
  - Fix out of range access in Intro.partialSort.
  - Update QuickCheck dependency bounds.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Tue Dec  3 2019 psimons@suse.com
- Update vector-algorithms to version 0.8.0.3.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Wed Oct 10 2018 psimons@suse.com
- Update vector-algorithms to version 0.8.0.1.
  Upstream does not provide a change log file.
* Thu Aug 30 2018 psimons@suse.com
- Update vector-algorithms to version 0.7.0.4.
  Upstream does not provide a change log file.
* Fri Aug 17 2018 psimons@suse.com
- Update Cabal build information to prevent build attempts with
  GHC 8.6.x.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jan  9 2017 psimons@suse.com
- Update to version 0.7.0.1 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.7.0.1 revision 0 with cabal2obs.
* Tue Nov 17 2015 mimi.vx@gmail.com
- initial commit
